@@ -2,12 +2,13 @@ use anyhow::{bail, Result};
 use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};
 
 use windows::Win32::{
-    Foundation::{ERROR_BUFFER_OVERFLOW, NO_ERROR},
+    Foundation::{ERROR_BUFFER_OVERFLOW, NO_ERROR, WIN32_ERROR},
     NetworkManagement::IpHelper::{
-        GetAdaptersAddresses, AF_INET, AF_INET6, AF_UNSPEC, GAA_FLAG_INCLUDE_TUNNEL_BINDINGORDER,
-        IP_ADAPTER_ADDRESSES_LH,
+        GetAdaptersAddresses, GAA_FLAG_INCLUDE_TUNNEL_BINDINGORDER, IP_ADAPTER_ADDRESSES_LH,
+    },
+    Networking::WinSock::{
+        ADDRESS_FAMILY, AF_INET, AF_INET6, AF_UNSPEC, SOCKADDR_IN, SOCKADDR_IN6,
     },
-    Networking::WinSock::{SOCKADDR_IN, SOCKADDR_IN6},
 };
 
 pub fn get_dns_servers() -> Result<Vec<IpAddr>> {
@@ -23,7 +24,7 @@ pub fn get_dns_servers() -> Result<Vec<IpAddr>> {
             &mut buf_size,
         );
 
-        match error {
+        match WIN32_ERROR(error) {
             ERROR_BUFFER_OVERFLOW => {}
             e => {
                 bail!("GetAdaptersAddresses#1 failed: {:?}", e);
@@ -45,7 +46,7 @@ pub fn get_dns_servers() -> Result<Vec<IpAddr>> {
             &mut buf_size,
         );
 
-        match error {
+        match WIN32_ERROR(error) {
             NO_ERROR => {}
             e => {
                 bail!("GetAdaptersAddresses#2 failed: {:?}", e);
@@ -75,7 +76,7 @@ unsafe fn get_adapter_dns_servers(a: &IP_ADAPTER_ADDRESSES_LH) -> Vec<IpAddr> {
     while !p_address.is_null() {
         let sock_addr = (*p_address).Address.lpSockaddr;
         if !sock_addr.is_null() {
-            match (*sock_addr).sa_family as u32 {
+            match ADDRESS_FAMILY((*sock_addr).sa_family as u32) {
                 AF_INET => {
                     let p_sockaddr_in: *const SOCKADDR_IN = sock_addr.cast();
                     let ipv4 = Ipv4Addr::from(u32::from_be((*p_sockaddr_in).sin_addr.S_un.S_addr));
